unit hiFileTools;

interface

uses
  Kol, Share, Windows, Debug;

type
  THIFileTools = class(TDebug)
    private
      function GetErrorCode: Integer;
      
    public
      _prop_DelToRecycle: Byte;
      _prop_Replace: Byte;
      _prop_FileName: string;
      _prop_NewFileName: string;        
      
      _data_NewFileName: THI_Event;
      _data_FileName: THI_Event;
      _data_Replace: THI_Event;
      
      _event_onEnd:THI_Event;
      _event_onError:THI_Event;

      procedure _work_doMove(var _Data: TData; Index: Word);
      procedure _work_doCopy(var _Data: TData; Index: Word);
      procedure _work_doDelete(var _Data: TData; Index: Word);
      procedure _work_doFileExists(var _Data: TData; Index: Word);
  end;

implementation

uses hiStr_Enum;

function THIFileTools.GetErrorCode: Integer;
begin
  Result := GetLastError;
  case Result of
    2: Result := 0; //    
    32: Result := 1; //       
    5: Result := 2;  //     " " / ""
    80, 183: Result := 3; //    ,  Replace = False (80 - Copy, 183 - Move)
    3: Result := 4; //    
  else 
    Result := 5; //  
  end;
end;

procedure THIFileTools._work_doMove;
var
  F1, F2: string;
  Flag: DWord;
begin
  F1 := ReadString(_Data,_data_FileName, _prop_FileName);
  F2 := ReadString(_Data,_data_NewFileName, _prop_NewFileName);
  
  if ReadInteger(_Data, _data_Replace, _prop_Replace) = 0 then Flag := 0 else Flag := 1;
  
  if MoveFileEx(PChar(F1), PChar(F2), Flag or MOVEFILE_COPY_ALLOWED {or MOVEFILE_WRITE_THROUGH}) then
    _hi_CreateEvent(_Data, @_event_onEnd)
  else
    _hi_CreateEvent(_Data, @_event_onError, GetErrorCode);
end;

procedure THIFileTools._work_doCopy;
var
  F1, F2: string;
  Flag: Boolean;
begin
  F1 := ReadString(_Data,_data_FileName, _prop_FileName);
  F2 := ReadString(_Data,_data_NewFileName, _prop_NewFileName);
  
  if ReadInteger(_Data, _data_Replace, _prop_Replace) = 0 then Flag := True else Flag := False;
  
  if CopyFile(PChar(F1), PChar(F2), Flag) then
    _hi_CreateEvent(_Data, @_event_onEnd)
  else
    _hi_CreateEvent(_Data, @_event_onError, GetErrorCode);
end;

procedure THIFileTools._work_doDelete;
var
  F1: string;
  
  function DeleteFiles(const DirPath: string): Boolean;
  var
    Files, Name: string;
  begin
    Files := GetFileListStr(ExtractFilePath(DirPath), ExtractFileName(DirPath));
    Result := True;
    while Files <> '' do
    begin
      Name := fParse(Files, ';');
      Result := Result and DeleteFile(PChar(Name));
    end;
  end;
  
begin
  F1 := ReadString(_Data, _data_FileName, _prop_FileName);
  if _prop_DelToRecycle = 0 then
    DeleteFile2Recycle(F1)
  else
    DeleteFiles(F1);
    
  if not FileExists(F1) then
    _hi_CreateEvent(_Data, @_event_onEnd);
end;

procedure THIFileTools._work_doFileExists;
begin
  _hi_CreateEvent(_Data, @_event_onEnd, Integer(FileExists(ReadString(_Data, _data_FileName, _prop_FileName))));
end;

end.
